summaryrefslogtreecommitdiffstats
path: root/src/kernel
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel')
-rw-r--r--src/kernel/ntqapplication.h6
-rw-r--r--src/kernel/ntqmetaobject.h6
-rw-r--r--src/kernel/ntqobjectdefs.h20
-rw-r--r--src/kernel/ntqpaintdevice.h4
-rw-r--r--src/kernel/qabstractlayout.cpp4
-rw-r--r--src/kernel/qaccel.cpp8
-rw-r--r--src/kernel/qapplication.cpp200
-rw-r--r--src/kernel/qapplication_p.h12
-rw-r--r--src/kernel/qapplication_x11.cpp152
-rw-r--r--src/kernel/qasyncimageio.cpp16
-rw-r--r--src/kernel/qclipboard_x11.cpp8
-rw-r--r--src/kernel/qdnd_x11.cpp4
-rw-r--r--src/kernel/qeventloop_x11.cpp12
-rw-r--r--src/kernel/qimage.cpp24
-rw-r--r--src/kernel/qjpegio.cpp8
-rw-r--r--src/kernel/qmetaobject.cpp30
-rw-r--r--src/kernel/qmime.cpp4
-rw-r--r--src/kernel/qobject.cpp24
-rw-r--r--src/kernel/qpixmap_x11.cpp6
-rw-r--r--src/kernel/qrichtext.cpp4
-rw-r--r--src/kernel/qstylesheet.cpp8
-rw-r--r--src/kernel/qwidget.cpp14
-rw-r--r--src/kernel/qwidget_x11.cpp16
23 files changed, 295 insertions, 295 deletions
diff --git a/src/kernel/ntqapplication.h b/src/kernel/ntqapplication.h
index 02c1993d..98a0ef0e 100644
--- a/src/kernel/ntqapplication.h
+++ b/src/kernel/ntqapplication.h
@@ -342,7 +342,7 @@ private:
friend void qt_mac_update_os_settings();
friend bool qt_set_socket_handler( int, int, TQObject *, bool);
friend void qt_mac_destroy_widget(TQWidget *);
- friend void qt_init(int *, char **, TQApplication::Type);
+ friend void tqt_init(int *, char **, TQApplication::Type);
#endif
#if defined(Q_WS_X11)
@@ -352,7 +352,7 @@ private slots:
private:
#ifdef QT_THREAD_SUPPORT
- static TQMutex *qt_mutex;
+ static TQMutex *tqt_mutex;
#endif // QT_THREAD_SUPPORT
int app_argc;
@@ -431,7 +431,7 @@ private:
friend class TQEvent;
friend class TQTranslator;
friend class TQEventLoop;
- friend Q_EXPORT void qt_ucm_initialize( TQApplication * );
+ friend Q_EXPORT void tqt_ucm_initialize( TQApplication * );
#if defined(Q_WS_WIN)
friend bool qt_sendSpontaneousEvent( TQObject*, TQEvent* );
#endif
diff --git a/src/kernel/ntqmetaobject.h b/src/kernel/ntqmetaobject.h
index c8289a1d..6c8fb094 100644
--- a/src/kernel/ntqmetaobject.h
+++ b/src/kernel/ntqmetaobject.h
@@ -157,7 +157,7 @@ public:
const TQMetaData * const signal_data, int n_signals,
const TQMetaProperty *const prop_data, int n_props,
const TQMetaEnum *const enum_data, int n_enums,
- bool (*qt_static_property)(TQObject*, int, int, TQVariant*),
+ bool (*tqt_static_property)(TQObject*, int, int, TQVariant*),
const TQClassInfo *const class_info, int n_info );
#endif
@@ -218,7 +218,7 @@ public:
const TQMetaData *const, int,
const TQMetaProperty *const prop_data, int n_props,
const TQMetaEnum *const enum_data, int n_enums,
- bool (*qt_static_property)(TQObject*, int, int, TQVariant*),
+ bool (*tqt_static_property)(TQObject*, int, int, TQVariant*),
const TQClassInfo *const class_info, int n_info );
TQStrList enumeratorNames( bool super = FALSE ) const;
int numEnumerators( bool super = FALSE ) const;
@@ -245,7 +245,7 @@ private:
#ifndef QT_NO_PROPERTIES
int propertyoffset;
public:
- bool qt_static_property( TQObject* o, int id, int f, TQVariant* v);
+ bool tqt_static_property( TQObject* o, int id, int f, TQVariant* v);
private:
friend class TQMetaProperty;
#endif
diff --git a/src/kernel/ntqobjectdefs.h b/src/kernel/ntqobjectdefs.h
index d9b18722..4d4e794f 100644
--- a/src/kernel/ntqobjectdefs.h
+++ b/src/kernel/ntqobjectdefs.h
@@ -64,8 +64,8 @@
#ifndef QT_NO_PROPERTIES
# define QT_PROP_FUNCTIONS \
- virtual bool qt_property( int id, int f, TQVariant* v); \
- static bool qt_static_property( TQObject* , int, int, TQVariant* );
+ virtual bool tqt_property( int id, int f, TQVariant* v); \
+ static bool tqt_static_property( TQObject* , int, int, TQVariant* );
#else
# define QT_PROP_FUNCTIONS
#endif
@@ -106,9 +106,9 @@ public: \
return staticMetaObject(); \
} \
virtual const char *className() const; \
- virtual void* qt_cast( const char* ); \
- virtual bool qt_invoke( int, TQUObject* ); \
- virtual bool qt_emit( int, TQUObject* ); \
+ virtual void* tqt_cast( const char* ); \
+ virtual bool tqt_invoke( int, TQUObject* ); \
+ virtual bool tqt_emit( int, TQUObject* ); \
QT_PROP_FUNCTIONS \
static TQMetaObject* staticMetaObject(); \
TQObject* qObject() { return (TQObject*)this; } \
@@ -165,13 +165,13 @@ class TQObjectList;
class TQObjectListIt;
class TQMemberDict;
-Q_EXPORT void *qt_find_obj_child( TQObject *, const char *, const char * );
+Q_EXPORT void *tqt_find_obj_child( TQObject *, const char *, const char * );
#define Q_CHILD(parent,type,name) \
- ((type*)qt_find_obj_child(parent,#type,name))
+ ((type*)tqt_find_obj_child(parent,#type,name))
-Q_EXPORT void *qt_inheritedBy( TQMetaObject *super, const TQObject *cls );
+Q_EXPORT void *tqt_inheritedBy( TQMetaObject *super, const TQObject *cls );
template <typename T>
-Q_INLINE_TEMPLATES T qt_cast(const TQObject *object)
-{ return (T)qt_inheritedBy( ((T)0)->staticMetaObject(), object ); }
+Q_INLINE_TEMPLATES T tqt_cast(const TQObject *object)
+{ return (T)tqt_inheritedBy( ((T)0)->staticMetaObject(), object ); }
#endif // TQOBJECTDEFS_H
diff --git a/src/kernel/ntqpaintdevice.h b/src/kernel/ntqpaintdevice.h
index 8b54afb4..898f9178 100644
--- a/src/kernel/ntqpaintdevice.h
+++ b/src/kernel/ntqpaintdevice.h
@@ -254,8 +254,8 @@ protected:
int, int, int, int, TQt::RasterOp, bool );
#endif
#if defined(Q_WS_X11)
- friend void qt_init_internal( int *, char **, Display *, TQt::HANDLE, TQt::HANDLE );
- friend void qt_cleanup();
+ friend void tqt_init_internal( int *, char **, Display *, TQt::HANDLE, TQt::HANDLE );
+ friend void tqt_cleanup();
#endif
private:
diff --git a/src/kernel/qabstractlayout.cpp b/src/kernel/qabstractlayout.cpp
index b0f0e8be..69cee62f 100644
--- a/src/kernel/qabstractlayout.cpp
+++ b/src/kernel/qabstractlayout.cpp
@@ -771,7 +771,7 @@ TQWidget *TQLayout::mainWidget()
{
if ( !topLevel ) {
if ( parent() ) {
- TQLayout *parentLayout = ::qt_cast<TQLayout*>(parent());
+ TQLayout *parentLayout = ::tqt_cast<TQLayout*>(parent());
Q_ASSERT(parentLayout);
return parentLayout->mainWidget();
} else {
@@ -891,7 +891,7 @@ bool TQLayout::eventFilter( TQObject *o, TQEvent *e )
TQWidget *w = (TQWidget *)c->child();
if ( !w->isTopLevel() ) {
#if !defined(QT_NO_MENUBAR) && !defined(QT_NO_TOOLBAR)
- if ( ::qt_cast<TQMenuBar*>(w) && !::qt_cast<TQToolBar*>(w->parentWidget()) )
+ if ( ::tqt_cast<TQMenuBar*>(w) && !::tqt_cast<TQToolBar*>(w->parentWidget()) )
menubar = (TQMenuBar *)w;
else
#endif
diff --git a/src/kernel/qaccel.cpp b/src/kernel/qaccel.cpp
index 3f761991..3acc3da5 100644
--- a/src/kernel/qaccel.cpp
+++ b/src/kernel/qaccel.cpp
@@ -193,15 +193,15 @@ private:
};
TQAccelManager* TQAccelManager::self_ptr = 0;
-bool Q_EXPORT qt_tryAccelEvent( TQWidget* w, TQKeyEvent* e){
+bool Q_EXPORT tqt_tryAccelEvent( TQWidget* w, TQKeyEvent* e){
return TQAccelManager::self()->tryAccelEvent( w, e );
}
-bool Q_EXPORT qt_dispatchAccelEvent( TQWidget* w, TQKeyEvent* e){
+bool Q_EXPORT tqt_dispatchAccelEvent( TQWidget* w, TQKeyEvent* e){
return TQAccelManager::self()->dispatchAccelEvent( w, e );
}
-bool Q_EXPORT qt_tryComposeUnicode( TQWidget* w, TQKeyEvent* e){
+bool Q_EXPORT tqt_tryComposeUnicode( TQWidget* w, TQKeyEvent* e){
return TQAccelManager::self()->tryComposeUnicode( w, e );
}
@@ -229,7 +229,7 @@ bool TQAccelManager::correctSubWindow( TQWidget* w, TQAccelPrivate* d ) {
/* if we live in a floating dock window, keep our parent's
* accelerators working */
#ifndef QT_NO_MAINWINDOW
- if ( tlw->isDialog() && tlw->parentWidget() && ::qt_cast<TQDockWindow*>(tlw) )
+ if ( tlw->isDialog() && tlw->parentWidget() && ::tqt_cast<TQDockWindow*>(tlw) )
return tlw->parentWidget()->topLevelWidget() == wtlw;
if ( wtlw != tlw )
diff --git a/src/kernel/qapplication.cpp b/src/kernel/qapplication.cpp
index 8cc05071..3dc3db74 100644
--- a/src/kernel/qapplication.cpp
+++ b/src/kernel/qapplication.cpp
@@ -312,28 +312,28 @@
*/
/*
- The qt_init() and qt_cleanup() functions are implemented in the
+ The tqt_init() and tqt_cleanup() functions are implemented in the
qapplication_xyz.cpp file.
*/
-void qt_init( int *, char **, TQApplication::Type );
-void qt_cleanup();
+void tqt_init( int *, char **, TQApplication::Type );
+void tqt_cleanup();
#if defined(Q_WS_X11)
-void qt_init( Display* dpy, TQt::HANDLE, TQt::HANDLE );
+void tqt_init( Display* dpy, TQt::HANDLE, TQt::HANDLE );
#endif
-Q_EXPORT bool qt_tryModalHelper( TQWidget *widget, TQWidget **rettop );
+Q_EXPORT bool tqt_tryModalHelper( TQWidget *widget, TQWidget **rettop );
TQApplication *tqApp = 0; // global application object
TQStyle *TQApplication::app_style = 0; // default application style
-bool qt_explicit_app_style = FALSE; // style explicitly set by programmer
+bool tqt_explicit_app_style = FALSE; // style explicitly set by programmer
int TQApplication::app_cspec = TQApplication::NormalColor;
#ifndef QT_NO_PALETTE
TQPalette *TQApplication::app_pal = 0; // default application palette
#endif
TQFont *TQApplication::app_font = 0; // default application font
-bool qt_app_has_font = FALSE;
+bool tqt_app_has_font = FALSE;
#ifndef QT_NO_CURSOR
TQCursor *TQApplication::app_cursor = 0; // default application cursor
#endif
@@ -350,10 +350,10 @@ int TQApplication::mouse_double_click_time = 400; // mouse dbl click limit
#ifndef QT_NO_WHEELEVENT
int TQApplication::wheel_scroll_lines = 3; // number of lines to scroll
#endif
-bool qt_is_gui_used;
+bool tqt_is_gui_used;
bool Q_EXPORT tqt_resolve_symlinks = TRUE;
bool Q_EXPORT tqt_tab_all_widgets = TRUE;
-TQRect qt_maxWindowRect;
+TQRect tqt_maxWindowRect;
static int drag_time = 500;
static int drag_distance = 4;
static bool reverse_layout = FALSE;
@@ -366,7 +366,7 @@ bool TQApplication::animate_tooltip = FALSE;
bool TQApplication::fade_tooltip = FALSE;
bool TQApplication::animate_toolbox = FALSE;
bool TQApplication::widgetCount = FALSE;
-TQApplication::Type qt_appType=TQApplication::Tty;
+TQApplication::Type tqt_appType=TQApplication::Tty;
#ifndef QT_NO_COMPONENT
TQStringList *TQApplication::app_libpaths = 0;
#endif
@@ -374,29 +374,29 @@ bool TQApplication::metaComposeUnicode = FALSE;
int TQApplication::composedUnicode = 0;
#ifdef QT_THREAD_SUPPORT
-TQMutex *TQApplication::qt_mutex = 0;
+TQMutex *TQApplication::tqt_mutex = 0;
static TQMutex *postevent_mutex = 0;
-static TQt::HANDLE qt_application_thread_id = 0;
+static TQt::HANDLE tqt_application_thread_id = 0;
Q_EXPORT TQt::HANDLE tqt_get_application_thread_id()
{
- return qt_application_thread_id;
+ return tqt_application_thread_id;
}
#endif // QT_THREAD_SUPPORT
TQEventLoop *TQApplication::eventloop = 0; // application event loop
#ifndef QT_NO_ACCEL
-extern bool qt_dispatchAccelEvent( TQWidget*, TQKeyEvent* ); // def in qaccel.cpp
-extern bool qt_tryComposeUnicode( TQWidget*, TQKeyEvent* ); // def in qaccel.cpp
+extern bool tqt_dispatchAccelEvent( TQWidget*, TQKeyEvent* ); // def in qaccel.cpp
+extern bool tqt_tryComposeUnicode( TQWidget*, TQKeyEvent* ); // def in qaccel.cpp
#endif
#if defined(QT_TABLET_SUPPORT)
bool chokeMouse = FALSE;
#endif
-void qt_setMaxWindowRect(const TQRect& r)
+void tqt_setMaxWindowRect(const TQRect& r)
{
- qt_maxWindowRect = r;
+ tqt_maxWindowRect = r;
// Re-resize any maximized windows
TQWidgetList* l = TQApplication::topLevelWidgets();
if ( l ) {
@@ -510,11 +510,11 @@ TQString *TQApplication::session_key = 0; // ## session key. Should be a member
#endif
TQWidgetList *TQApplication::popupWidgets = 0; // has keyboard input focus
-TQDesktopWidget *qt_desktopWidget = 0; // root window widgets
+TQDesktopWidget *tqt_desktopWidget = 0; // root window widgets
#ifndef QT_NO_CLIPBOARD
-TQClipboard *qt_clipboard = 0; // global clipboard object
+TQClipboard *tqt_clipboard = 0; // global clipboard object
#endif
-TQWidgetList * qt_modal_stack=0; // stack of modal widgets
+TQWidgetList * tqt_modal_stack=0; // stack of modal widgets
// Definitions for posted events
struct TQPostEvent {
@@ -553,12 +553,12 @@ uint qGlobalPostedEventsCount()
static TQSingleCleanupHandler<TQPostEventList> qapp_cleanup_events;
#ifndef QT_NO_PALETTE
-TQPalette *qt_std_pal = 0;
+TQPalette *tqt_std_pal = 0;
-void qt_create_std_palette()
+void tqt_create_std_palette()
{
- if ( qt_std_pal )
- delete qt_std_pal;
+ if ( tqt_std_pal )
+ delete tqt_std_pal;
TQColor standardLightGray( 192, 192, 192 );
TQColor light( 255, 255, 255 );
@@ -572,10 +572,10 @@ void qt_create_std_palette()
TQColorGroup std_inact( TQt::black, standardLightGray,
light, dark, TQt::gray,
TQt::black, TQt::white );
- qt_std_pal = new TQPalette( std_act, std_dis, std_inact );
+ tqt_std_pal = new TQPalette( std_act, std_dis, std_inact );
}
-static void qt_fix_tooltips()
+static void tqt_fix_tooltips()
{
// No resources for this yet (unlike on Windows).
TQColorGroup cg( TQt::black, TQColor(255,255,220),
@@ -589,7 +589,7 @@ static void qt_fix_tooltips()
void TQApplication::process_cmdline( int* argcptr, char ** argv )
{
// process platform-indep command line
- if ( !qt_is_gui_used || !*argcptr)
+ if ( !tqt_is_gui_used || !*argcptr)
return;
int argc = *argcptr;
@@ -789,7 +789,7 @@ TQApplication::TQApplication( int &argc, char **argv, Type type )
construct( argc, argv, type );
}
-Q_EXPORT void qt_ucm_initialize( TQApplication *theApp )
+Q_EXPORT void tqt_ucm_initialize( TQApplication *theApp )
{
if ( tqApp )
return;
@@ -802,8 +802,8 @@ Q_EXPORT void qt_ucm_initialize( TQApplication *theApp )
void TQApplication::construct( int &argc, char **argv, Type type )
{
- qt_appType = type;
- qt_is_gui_used = (type != Tty);
+ tqt_appType = type;
+ tqt_is_gui_used = (type != Tty);
init_precmdline();
static const char *empty = "";
if ( argc == 0 || argv == 0 ) {
@@ -813,11 +813,11 @@ void TQApplication::construct( int &argc, char **argv, Type type )
app_argc = argc;
app_argv = argv;
- qt_init( &argc, argv, type ); // Must be called before initialize()
+ tqt_init( &argc, argv, type ); // Must be called before initialize()
process_cmdline( &argc, argv );
initialize( argc, argv );
- if ( qt_is_gui_used )
- qt_maxWindowRect = desktop()->rect();
+ if ( tqt_is_gui_used )
+ tqt_maxWindowRect = desktop()->rect();
if ( eventloop )
eventloop->appStartingUp();
}
@@ -828,7 +828,7 @@ void TQApplication::construct( int &argc, char **argv, Type type )
TQApplication::Type TQApplication::type() const
{
- return qt_appType;
+ return tqt_appType;
}
#if defined(Q_WS_X11)
@@ -854,9 +854,9 @@ TQApplication::TQApplication( Display* dpy, HANDLE visual, HANDLE colormap )
app_argc = aargc;
app_argv = aargv;
- qt_appType = GuiClient;
- qt_is_gui_used = TRUE;
- qt_appType = GuiClient;
+ tqt_appType = GuiClient;
+ tqt_is_gui_used = TRUE;
+ tqt_appType = GuiClient;
init_precmdline();
// ... no command line.
@@ -865,15 +865,15 @@ TQApplication::TQApplication( Display* dpy, HANDLE visual, HANDLE colormap )
tqWarning( "TQApplication: invalid Display* argument." );
#endif // QT_CHECK_STATE
- qt_init( &aargc, aargv, GuiClient );
+ tqt_init( &aargc, aargv, GuiClient );
} else {
- qt_init( dpy, visual, colormap );
+ tqt_init( dpy, visual, colormap );
}
initialize( aargc, aargv );
- if ( qt_is_gui_used )
- qt_maxWindowRect = desktop()->rect();
+ if ( tqt_is_gui_used )
+ tqt_maxWindowRect = desktop()->rect();
if ( eventloop )
eventloop->appStartingUp();
}
@@ -893,9 +893,9 @@ TQApplication::TQApplication( Display* dpy, HANDLE visual, HANDLE colormap )
TQApplication::TQApplication(Display *dpy, int argc, char **argv,
HANDLE visual, HANDLE colormap)
{
- qt_appType = GuiClient;
- qt_is_gui_used = TRUE;
- qt_appType = GuiClient;
+ tqt_appType = GuiClient;
+ tqt_is_gui_used = TRUE;
+ tqt_appType = GuiClient;
init_precmdline();
app_argc = argc;
@@ -906,16 +906,16 @@ TQApplication::TQApplication(Display *dpy, int argc, char **argv,
tqWarning( "TQApplication: invalid Display* argument." );
#endif // QT_CHECK_STATE
- qt_init( &argc, argv, GuiClient );
+ tqt_init( &argc, argv, GuiClient );
} else {
- qt_init(dpy, visual, colormap);
+ tqt_init(dpy, visual, colormap);
}
process_cmdline( &argc, argv );
initialize(argc, argv);
- if ( qt_is_gui_used )
- qt_maxWindowRect = desktop()->rect();
+ if ( tqt_is_gui_used )
+ tqt_maxWindowRect = desktop()->rect();
if ( eventloop )
eventloop->appStartingUp();
}
@@ -945,9 +945,9 @@ void TQApplication::init_precmdline()
void TQApplication::initialize( int argc, char **argv )
{
#ifdef QT_THREAD_SUPPORT
- qt_mutex = new TQMutex( TRUE );
+ tqt_mutex = new TQMutex( TRUE );
postevent_mutex = new TQMutex( TRUE );
- qt_application_thread_id = TQThread::currentThread();
+ tqt_application_thread_id = TQThread::currentThread();
#endif // QT_THREAD_SUPPORT
app_argc = argc;
@@ -1012,7 +1012,7 @@ TQWidget *TQApplication::activePopupWidget()
TQWidget *TQApplication::activeModalWidget()
{
- return qt_modal_stack ? qt_modal_stack->getFirst() : 0;
+ return tqt_modal_stack ? tqt_modal_stack->getFirst() : 0;
}
/*!
@@ -1024,9 +1024,9 @@ TQApplication::~TQApplication()
{
#ifndef QT_NO_CLIPBOARD
// flush clipboard contents
- if ( qt_clipboard ) {
+ if ( tqt_clipboard ) {
TQCustomEvent event( TQEvent::Clipboard );
- TQApplication::sendEvent( qt_clipboard, &event );
+ TQApplication::sendEvent( tqt_clipboard, &event );
}
#endif
@@ -1046,18 +1046,18 @@ TQApplication::~TQApplication()
TQObject *tipmanager = child( "toolTipManager", "TQTipManager", FALSE );
delete tipmanager;
- delete qt_desktopWidget;
- qt_desktopWidget = 0;
+ delete tqt_desktopWidget;
+ tqt_desktopWidget = 0;
is_app_closing = TRUE;
#ifndef QT_NO_CLIPBOARD
- delete qt_clipboard;
- qt_clipboard = 0;
+ delete tqt_clipboard;
+ tqt_clipboard = 0;
#endif
TQWidget::destroyMapper();
#ifndef QT_NO_PALETTE
- delete qt_std_pal;
- qt_std_pal = 0;
+ delete tqt_std_pal;
+ tqt_std_pal = 0;
delete app_pal;
app_pal = 0;
delete app_palettes;
@@ -1084,7 +1084,7 @@ TQApplication::~TQApplication()
delete qt_dnd_manager;
#endif
- qt_cleanup();
+ tqt_cleanup();
#ifndef QT_NO_COMPONENT
delete app_libpaths;
@@ -1092,8 +1092,8 @@ TQApplication::~TQApplication()
#endif
#ifdef QT_THREAD_SUPPORT
- delete qt_mutex;
- qt_mutex = 0;
+ delete tqt_mutex;
+ tqt_mutex = 0;
delete postevent_mutex;
postevent_mutex = 0;
#endif // QT_THREAD_SUPPORT
@@ -1115,8 +1115,8 @@ TQApplication::~TQApplication()
session_key = 0;
#endif //QT_NO_SESSIONMANAGER
- qt_explicit_app_style = FALSE;
- qt_app_has_font = FALSE;
+ tqt_explicit_app_style = FALSE;
+ tqt_app_has_font = FALSE;
app_tracking = 0;
obey_desktop_settings = TRUE;
cursor_flash_time = 1000;
@@ -1213,7 +1213,7 @@ TQStyle& TQApplication::style()
#ifndef QT_NO_STYLE
if ( app_style )
return *app_style;
- if ( !qt_is_gui_used )
+ if ( !tqt_is_gui_used )
tqFatal( "No style available in non-gui applications!" );
#if defined(Q_WS_X11)
@@ -1305,7 +1305,7 @@ void TQApplication::setStyle( TQStyle *style )
TQStyle* old = app_style;
app_style = style;
#ifdef Q_WS_X11
- qt_explicit_app_style = TRUE;
+ tqt_explicit_app_style = TRUE;
#endif // Q_WS_X11
if ( startingUp() ) {
@@ -1332,9 +1332,9 @@ void TQApplication::setStyle( TQStyle *style )
// take care of possible palette requirements of certain gui
// styles. Do it before polishing the application since the style
// might call TQApplication::setStyle() itself
- if ( !qt_std_pal )
- qt_create_std_palette();
- TQPalette tmpPal = *qt_std_pal;
+ if ( !tqt_std_pal )
+ tqt_create_std_palette();
+ TQPalette tmpPal = *tqt_std_pal;
setPalette( tmpPal, TRUE );
// initialize the application with the new style
@@ -1381,7 +1381,7 @@ void TQApplication::setStyle( TQStyle *style )
TQStyle* TQApplication::setStyle( const TQString& style )
{
#ifdef Q_WS_X11
- qt_explicit_app_style = TRUE;
+ tqt_explicit_app_style = TRUE;
#endif // Q_WS_X11
if ( startingUp() ) {
@@ -1826,10 +1826,10 @@ TQPalette TQApplication::palette(const TQWidget* w)
"called after the TQApplication object has been created" );
#endif
if ( !app_pal ) {
- if ( !qt_std_pal )
- qt_create_std_palette();
- app_pal = new TQPalette( *qt_std_pal );
- qt_fix_tooltips();
+ if ( !tqt_std_pal )
+ tqt_create_std_palette();
+ app_pal = new TQPalette( *tqt_std_pal );
+ tqt_fix_tooltips();
}
if ( w && app_palettes ) {
@@ -1885,7 +1885,7 @@ void TQApplication::setPalette( const TQPalette &palette, bool informWidgets,
all = app_palettes != 0;
delete app_palettes;
app_palettes = 0;
- qt_fix_tooltips();
+ tqt_fix_tooltips();
} else {
if ( !app_palettes ) {
app_palettes = new TQAsciiDict<TQPalette>;
@@ -1961,7 +1961,7 @@ void TQApplication::setFont( const TQFont &font, bool informWidgets,
{
bool all = FALSE;
if ( !className ) {
- qt_app_has_font = TRUE;
+ tqt_app_has_font = TRUE;
if ( !app_font ) {
app_font = new TQFont( font );
TQ_CHECK_PTR( app_font );
@@ -2367,7 +2367,7 @@ bool TQApplication::notify( TQObject *receiver, TQEvent *e )
res = internalNotify( receiver, e );
if ( !res && !key->isAccepted() )
- res = qt_dispatchAccelEvent( (TQWidget*)receiver, key );
+ res = tqt_dispatchAccelEvent( (TQWidget*)receiver, key );
// next lines are for compatibility with TQt <= 3.0.x: old
// TQAccel was listening on toplevel widgets
@@ -2383,7 +2383,7 @@ bool TQApplication::notify( TQObject *receiver, TQEvent *e )
TQWidget* w = (TQWidget*)receiver;
TQKeyEvent* key = (TQKeyEvent*) e;
#ifndef QT_NO_ACCEL
- if ( qt_tryComposeUnicode( w, key ) )
+ if ( tqt_tryComposeUnicode( w, key ) )
break;
#endif
bool def = key->isAccepted();
@@ -3596,7 +3596,7 @@ void TQApplication::setActiveWindow( TQWidget* act )
Creates the proper Enter/Leave event when widget \a enter is entered
and widget \a leave is left.
*/
-Q_EXPORT void qt_dispatchEnterLeave( TQWidget* enter, TQWidget* leave ) {
+Q_EXPORT void tqt_dispatchEnterLeave( TQWidget* enter, TQWidget* leave ) {
#if 0
if ( leave ) {
TQEvent e( TQEvent::Leave );
@@ -3666,19 +3666,19 @@ Q_EXPORT void qt_dispatchEnterLeave( TQWidget* enter, TQWidget* leave ) {
TQEvent leaveEvent( TQEvent::Leave );
for ( w = leaveList.first(); w; w = leaveList.next() ) {
- if ( !tqApp->activeModalWidget() || qt_tryModalHelper( w, 0 ))
+ if ( !tqApp->activeModalWidget() || tqt_tryModalHelper( w, 0 ))
TQApplication::sendEvent( w, &leaveEvent );
}
TQEvent enterEvent( TQEvent::Enter );
for ( w = enterList.first(); w; w = enterList.next() ) {
- if ( !tqApp->activeModalWidget() || qt_tryModalHelper( w, 0 ))
+ if ( !tqApp->activeModalWidget() || tqt_tryModalHelper( w, 0 ))
TQApplication::sendEvent( w, &enterEvent );
}
}
#ifdef Q_WS_MACX
-extern TQWidget *qt_tryModalHelperMac( TQWidget * top ); //qapplication_mac.cpp
+extern TQWidget *tqt_tryModalHelperMac( TQWidget * top ); //qapplication_mac.cpp
#endif
@@ -3687,7 +3687,7 @@ extern TQWidget *qt_tryModalHelperMac( TQWidget * top ); //qapplication_mac.cpp
Called from qapplication_<platform>.cpp, returns TRUE
if the widget should accept the event.
*/
-Q_EXPORT bool qt_tryModalHelper( TQWidget *widget, TQWidget **rettop ) {
+Q_EXPORT bool tqt_tryModalHelper( TQWidget *widget, TQWidget **rettop ) {
TQWidget *modal=0, *top=TQApplication::activeModalWidget();
if ( rettop ) *rettop = top;
@@ -3695,7 +3695,7 @@ Q_EXPORT bool qt_tryModalHelper( TQWidget *widget, TQWidget **rettop ) {
return TRUE;
#ifdef Q_WS_MACX
- top = qt_tryModalHelperMac( top );
+ top = tqt_tryModalHelperMac( top );
if ( rettop ) *rettop = top;
#endif
@@ -3718,15 +3718,15 @@ Q_EXPORT bool qt_tryModalHelper( TQWidget *widget, TQWidget **rettop ) {
groupLeader = groupLeader->parentWidget();
if ( groupLeader ) {
- // Does groupLeader have a child in qt_modal_stack?
+ // Does groupLeader have a child in tqt_modal_stack?
bool unrelated = TRUE;
- modal = qt_modal_stack->first();
+ modal = tqt_modal_stack->first();
while (modal && unrelated) {
TQWidget* p = modal->parentWidget();
while ( p && p != groupLeader && !p->testWFlags( TQt::WGroupLeader) ) {
p = p->parentWidget();
}
- modal = qt_modal_stack->next();
+ modal = tqt_modal_stack->next();
if ( p == groupLeader ) unrelated = FALSE;
}
@@ -3754,12 +3754,12 @@ Q_EXPORT bool qt_tryModalHelper( TQWidget *widget, TQWidget **rettop ) {
TQDesktopWidget *TQApplication::desktop()
{
- if ( !qt_desktopWidget || // not created yet
- !qt_desktopWidget->isDesktop() ) { // reparented away
- qt_desktopWidget = new TQDesktopWidget();
- TQ_CHECK_PTR( qt_desktopWidget );
+ if ( !tqt_desktopWidget || // not created yet
+ !tqt_desktopWidget->isDesktop() ) { // reparented away
+ tqt_desktopWidget = new TQDesktopWidget();
+ TQ_CHECK_PTR( tqt_desktopWidget );
}
- return qt_desktopWidget;
+ return tqt_desktopWidget;
}
#ifndef QT_NO_CLIPBOARD
@@ -3768,11 +3768,11 @@ TQDesktopWidget *TQApplication::desktop()
*/
TQClipboard *TQApplication::clipboard()
{
- if ( qt_clipboard == 0 ) {
- qt_clipboard = new TQClipboard;
- TQ_CHECK_PTR( qt_clipboard );
+ if ( tqt_clipboard == 0 ) {
+ tqt_clipboard = new TQClipboard;
+ TQ_CHECK_PTR( tqt_clipboard );
}
- return qt_clipboard;
+ return tqt_clipboard;
}
#endif // QT_NO_CLIPBOARD
@@ -3859,12 +3859,12 @@ bool TQApplication::desktopSettingsAware()
#if defined(QT_THREAD_SUPPORT)
void TQApplication::lock()
{
- qt_mutex->lock();
+ tqt_mutex->lock();
}
void TQApplication::unlock(bool wakeUpGui)
{
- qt_mutex->unlock();
+ tqt_mutex->unlock();
if (wakeUpGui)
wakeUpGuiThread();
@@ -3872,12 +3872,12 @@ void TQApplication::unlock(bool wakeUpGui)
bool TQApplication::locked()
{
- return qt_mutex->locked();
+ return tqt_mutex->locked();
}
bool TQApplication::tryLock()
{
- return qt_mutex->tryLock();
+ return tqt_mutex->tryLock();
}
#endif
diff --git a/src/kernel/qapplication_p.h b/src/kernel/qapplication_p.h
index ae7568b8..766a8c40 100644
--- a/src/kernel/qapplication_p.h
+++ b/src/kernel/qapplication_p.h
@@ -66,12 +66,12 @@ class TQMouseEvent;
class TQWheelEvent;
extern Q_EXPORT bool tqt_modal_state();
-extern Q_EXPORT void qt_enter_modal( TQWidget* );
-extern Q_EXPORT void qt_leave_modal( TQWidget* );
+extern Q_EXPORT void tqt_enter_modal( TQWidget* );
+extern Q_EXPORT void tqt_leave_modal( TQWidget* );
-extern bool qt_is_gui_used;
+extern bool tqt_is_gui_used;
#ifndef QT_NO_CLIPBOARD
-extern TQClipboard *qt_clipboard;
+extern TQClipboard *tqt_clipboard;
#endif
#if defined (Q_OS_WIN32) || defined (Q_OS_CYGWIN)
@@ -89,7 +89,7 @@ extern int qt_ncols_option;
#endif
-extern void qt_dispatchEnterLeave( TQWidget*, TQWidget* );
-extern bool qt_tryModalHelper( TQWidget *, TQWidget ** = 0 );
+extern void tqt_dispatchEnterLeave( TQWidget*, TQWidget* );
+extern bool tqt_tryModalHelper( TQWidget *, TQWidget ** = 0 );
#endif
diff --git a/src/kernel/qapplication_x11.cpp b/src/kernel/qapplication_x11.cpp
index 44ff475c..874afe06 100644
--- a/src/kernel/qapplication_x11.cpp
+++ b/src/kernel/qapplication_x11.cpp
@@ -228,7 +228,7 @@ Atom qt_net_wm_ping = 0; // _NET_WM_PING protocol
static Atom qt_xsetroot_id = 0;
Atom qt_xa_clipboard = 0;
Atom qt_selection_property = 0;
-Atom qt_clipboard_sentinel = 0;
+Atom tqt_clipboard_sentinel = 0;
Atom qt_selection_sentinel = 0;
Q_EXPORT Atom tqt_wm_state = 0;
Atom qt_wm_change_state = 0;
@@ -359,7 +359,7 @@ static Time mouseButtonPressTime = 0; // when was a button pressed
static short mouseXPos, mouseYPos; // mouse pres position in act window
static short mouseGlobalXPos, mouseGlobalYPos; // global mouse press position
-extern TQWidgetList *qt_modal_stack; // stack of modal widgets
+extern TQWidgetList *tqt_modal_stack; // stack of modal widgets
static bool ignoreNextMouseReleaseEvent = FALSE; // ignore the next mouse release
// event if return from a modal
// widget
@@ -442,14 +442,14 @@ extern bool qt_check_clipboard_sentinel(); //def in qclipboard_x11.cpp
extern bool qt_check_selection_sentinel(); //def in qclipboard_x11.cpp
static void qt_save_rootinfo();
-bool qt_try_modal( TQWidget *, XEvent * );
+bool tqt_try_modal( TQWidget *, XEvent * );
int qt_ncols_option = 216; // used in qcolor_x11.cpp
int qt_visual_option = -1;
bool qt_cmap_option = FALSE;
TQWidget *qt_button_down = 0; // widget got last button-down
-extern bool qt_tryAccelEvent( TQWidget*, TQKeyEvent* ); // def in qaccel.cpp
+extern bool tqt_tryAccelEvent( TQWidget*, TQKeyEvent* ); // def in qaccel.cpp
struct TQScrollInProgress {
static long serial;
@@ -491,8 +491,8 @@ extern Atom qt_xdnd_selection;
extern bool qt_xdnd_dragging;
// gui or non-gui from qapplication.cpp
-extern bool qt_is_gui_used;
-extern bool qt_app_has_font;
+extern bool tqt_is_gui_used;
+extern bool tqt_app_has_font;
static bool qt_x11_cmdline_font = false;
@@ -505,8 +505,8 @@ extern void qt_clear_paintevent_clipping();
// Palette handling
-extern TQPalette *qt_std_pal;
-extern void qt_create_std_palette();
+extern TQPalette *tqt_std_pal;
+extern void tqt_create_std_palette();
void qt_x11_intern_atom( const char *, Atom * );
@@ -819,7 +819,7 @@ static int qt_xio_errhandler( Display * )
#endif
-// Memory leak: if the app exits before qt_init_internal(), this dict
+// Memory leak: if the app exits before tqt_init_internal(), this dict
// isn't released correctly.
static TQAsciiDict<Atom> *atoms_to_be_created = 0;
static bool create_atoms_now = 0;
@@ -828,7 +828,7 @@ static bool create_atoms_now = 0;
qt_x11_intern_atom() - efficiently interns an atom, now or later.
If the application is being initialized, this function stores the
- adddress of the atom and qt_init_internal will do the actual work
+ adddress of the atom and tqt_init_internal will do the actual work
tquickly. If the application is running, the atom is created here.
Neither argument may point to temporary variables.
@@ -902,8 +902,8 @@ static void qt_x11_process_intern_atoms()
*/
bool TQApplication::x11_apply_settings()
{
- if (! qt_std_pal)
- qt_create_std_palette();
+ if (! tqt_std_pal)
+ tqt_create_std_palette();
Atom type;
int format;
@@ -1000,13 +1000,13 @@ bool TQApplication::x11_apply_settings()
pal.disabled().foreground() );
}
- if (pal != *qt_std_pal && pal != TQApplication::palette()) {
+ if (pal != *tqt_std_pal && pal != TQApplication::palette()) {
TQApplication::setPalette(pal, TRUE);
- *qt_std_pal = pal;
+ *tqt_std_pal = pal;
}
TQFont font(TQApplication::font());
- if ( !qt_app_has_font && !qt_x11_cmdline_font ) {
+ if ( !tqt_app_has_font && !qt_x11_cmdline_font ) {
// read new font
str = settings.readEntry("/qt/font");
if (! str.isNull() && ! str.isEmpty()) {
@@ -1028,12 +1028,12 @@ bool TQApplication::x11_apply_settings()
}
// read new TQStyle
- extern bool qt_explicit_app_style; // defined in qapplication.cpp
+ extern bool tqt_explicit_app_style; // defined in qapplication.cpp
TQString stylename = settings.readEntry( "/qt/style" );
- if ( !stylename.isEmpty() && !qt_explicit_app_style ) {
+ if ( !stylename.isEmpty() && !tqt_explicit_app_style ) {
TQApplication::setStyle( stylename );
// took the style from the user settings, so mark the explicit flag FALSE
- qt_explicit_app_style = FALSE;
+ tqt_explicit_app_style = FALSE;
}
num =
@@ -1203,8 +1203,8 @@ static void qt_set_input_encoding()
static void qt_set_x11_resources( const char* font = 0, const char* fg = 0,
const char* bg = 0, const char* button = 0 )
{
- if ( !qt_std_pal )
- qt_create_std_palette();
+ if ( !tqt_std_pal )
+ tqt_create_std_palette();
TQCString resFont, resFG, resBG, resEF, sysFont;
@@ -1303,7 +1303,7 @@ static void qt_set_x11_resources( const char* font = 0, const char* fg = 0,
resFG = fg;
if ( resBG.isEmpty() )
resBG = bg;
- if ( (!qt_app_has_font || qt_x11_cmdline_font) && !resFont.isEmpty() ) { // set application font
+ if ( (!tqt_app_has_font || qt_x11_cmdline_font) && !resFont.isEmpty() ) { // set application font
TQFont fnt;
fnt.setRawName( resFont );
@@ -1341,17 +1341,17 @@ static void qt_set_x11_resources( const char* font = 0, const char* fg = 0,
if ( !resBG.isEmpty() )
bg = TQColor(TQString(resBG));
else
- bg = qt_std_pal->active().background();
+ bg = tqt_std_pal->active().background();
if ( !resFG.isEmpty() )
fg = TQColor(TQString(resFG));
else
- fg = qt_std_pal->active().foreground();
+ fg = tqt_std_pal->active().foreground();
if ( button )
btn = TQColor( button );
else if ( !resBG.isEmpty() )
btn = bg;
else
- btn = qt_std_pal->active().button();
+ btn = tqt_std_pal->active().button();
int h,s,v;
fg.hsv(&h,&s,&v);
@@ -1384,9 +1384,9 @@ static void qt_set_x11_resources( const char* font = 0, const char* fg = 0,
dcg.setColor( TQColorGroup::Highlight, TQt::darkBlue );
}
TQPalette pal( cg, dcg, cg );
- if ( pal != *qt_std_pal && pal != TQApplication::palette() )
+ if ( pal != *tqt_std_pal && pal != TQApplication::palette() )
TQApplication::setPalette( pal, TRUE );
- *qt_std_pal = pal;
+ *tqt_std_pal = pal;
}
if ( !resEF.isEmpty() ) {
@@ -1626,7 +1626,7 @@ static Visual *find_truecolor_visual( Display *dpy, int scr, int *depth, int *nc
/*****************************************************************************
- qt_init() - initializes TQt for X11
+ tqt_init() - initializes TQt for X11
*****************************************************************************/
#define XK_MISCELLANY
@@ -1639,14 +1639,14 @@ static Visual *find_truecolor_visual( Display *dpy, int scr, int *depth, int *nc
// ### in ntqpaintdevice.h which then should have a static too but can't have
// ### it because "storage class specifiers invalid in friend function
// ### declarations" :-) Ideas anyone?
-void qt_init_internal( int *argcptr, char **argv,
+void tqt_init_internal( int *argcptr, char **argv,
Display *display, TQt::HANDLE visual, TQt::HANDLE colormap )
{
setlocale( LC_ALL, "" ); // use correct char set mapping
setlocale( LC_NUMERIC, "C" ); // make sprintf()/scanf() work
#if defined(QT_THREAD_SUPPORT)
- if ( qt_is_gui_used ) {
+ if ( tqt_is_gui_used ) {
XInitThreads();
}
#endif
@@ -1804,7 +1804,7 @@ void qt_init_internal( int *argcptr, char **argv,
#endif
// Connect to X server
- if( qt_is_gui_used ) {
+ if( tqt_is_gui_used ) {
if ( ( appDpy = XOpenDisplay(appDpyName) ) == 0 ) {
tqWarning( "%s: cannot connect to X server %s", appName,
XDisplayName(appDpyName) );
@@ -1820,7 +1820,7 @@ void qt_init_internal( int *argcptr, char **argv,
// Get X parameters
- if( qt_is_gui_used ) {
+ if( tqt_is_gui_used ) {
appScreen = DefaultScreen(appDpy);
appScreenCount = ScreenCount(appDpy);
@@ -1990,7 +1990,7 @@ void qt_init_internal( int *argcptr, char **argv,
qt_x11_intern_atom( "INCR", &qt_x_incr );
qt_x11_intern_atom( "_XSETROOT_ID", &qt_xsetroot_id );
qt_x11_intern_atom( "_QT_SELECTION", &qt_selection_property );
- qt_x11_intern_atom( "_QT_CLIPBOARD_SENTINEL", &qt_clipboard_sentinel );
+ qt_x11_intern_atom( "_QT_CLIPBOARD_SENTINEL", &tqt_clipboard_sentinel );
qt_x11_intern_atom( "_QT_SELECTION_SENTINEL", &qt_selection_sentinel );
qt_x11_intern_atom( "_QT_SCROLL_DONE", &qt_qt_scrolldone );
qt_x11_intern_atom( "_QT_INPUT_ENCODING", &qt_input_encoding );
@@ -2205,7 +2205,7 @@ void qt_init_internal( int *argcptr, char **argv,
TQThread::initialize();
#endif
- if( qt_is_gui_used ) {
+ if( tqt_is_gui_used ) {
tqApp->setName( appName );
int screen;
@@ -2221,7 +2221,7 @@ void qt_init_internal( int *argcptr, char **argv,
}
}
- if ( qt_is_gui_used ) {
+ if ( tqt_is_gui_used ) {
qt_set_input_encoding();
qt_set_x11_resources( appFont, appFGCol, appBGCol, appBTNCol);
@@ -2235,7 +2235,7 @@ void qt_init_internal( int *argcptr, char **argv,
(int) ( ( ( TQPaintDevice::x11AppDpiY() >= 95 ? 17. : 12. ) *
72. / (float) TQPaintDevice::x11AppDpiY() ) + 0.5 );
- if ( !qt_app_has_font && !qt_x11_cmdline_font ) {
+ if ( !tqt_app_has_font && !qt_x11_cmdline_font ) {
TQFont f( "Helvetica", ptsz );
TQApplication::setFont( f );
}
@@ -2454,29 +2454,29 @@ void TQApplication::x11_initialize_style()
}
#endif
-void qt_init( int *argcptr, char **argv, TQApplication::Type )
+void tqt_init( int *argcptr, char **argv, TQApplication::Type )
{
- qt_init_internal( argcptr, argv, 0, 0, 0 );
+ tqt_init_internal( argcptr, argv, 0, 0, 0 );
}
-void qt_init( Display *display, TQt::HANDLE visual, TQt::HANDLE colormap )
+void tqt_init( Display *display, TQt::HANDLE visual, TQt::HANDLE colormap )
{
- qt_init_internal( 0, 0, display, visual, colormap );
+ tqt_init_internal( 0, 0, display, visual, colormap );
}
/*****************************************************************************
- qt_cleanup() - cleans up when the application is finished
+ tqt_cleanup() - cleans up when the application is finished
*****************************************************************************/
-void qt_cleanup()
+void tqt_cleanup()
{
appliedstamp = 0;
if ( app_save_rootinfo ) // root window must keep state
qt_save_rootinfo();
- if ( qt_is_gui_used ) {
+ if ( tqt_is_gui_used ) {
TQPixmapCache::clear();
TQPainter::cleanup();
TQCursor::cleanup();
@@ -2503,7 +2503,7 @@ void qt_cleanup()
#endif
#endif
- if ( qt_is_gui_used ) {
+ if ( tqt_is_gui_used ) {
int screen;
for ( screen = 0; screen < appScreenCount; screen++ ) {
if ( ! TQPaintDevice::x11AppDefaultColormap( screen ) )
@@ -2526,7 +2526,7 @@ void qt_cleanup()
XSetErrorHandler( original_x_errhandler );
XSetIOErrorHandler( original_xio_errhandler );
- if ( qt_is_gui_used && !appForeignDpy )
+ if ( tqt_is_gui_used && !appForeignDpy )
XCloseDisplay( appDpy ); // close X display
appDpy = 0;
@@ -2820,7 +2820,7 @@ void TQApplication::setMainWidget( TQWidget *mainWidget )
TQApplication cursor stack
*****************************************************************************/
-extern void qt_x11_enforce_cursor( TQWidget * w );
+extern void tqt_x11_enforce_cursor( TQWidget * w );
typedef TQPtrList<TQCursor> TQCursorList;
@@ -2886,7 +2886,7 @@ void TQApplication::setOverrideCursor( const TQCursor &cursor, bool replace )
register TQWidget *w;
while ( (w=it.current()) ) { // for all widgets that have
if ( w->testWState( WState_OwnCursor ) )
- qt_x11_enforce_cursor( w );
+ tqt_x11_enforce_cursor( w );
++it;
}
XFlush( appDpy ); // make X execute it NOW
@@ -2914,7 +2914,7 @@ void TQApplication::restoreOverrideCursor()
register TQWidget *w;
while ( (w=it.current()) ) { // set back to original cursors
if ( w->testWState( WState_OwnCursor ) )
- qt_x11_enforce_cursor( w );
+ tqt_x11_enforce_cursor( w );
++it;
}
XFlush( appDpy );
@@ -3429,7 +3429,7 @@ int TQApplication::x11ProcessEvent( XEvent* event )
if ( event->type == PropertyNotify ) { // some properties changed
if ( event->xproperty.window == TQPaintDevice::x11AppRootWindow( 0 ) ) {
// root properties for the first screen
- if ( event->xproperty.atom == qt_clipboard_sentinel ) {
+ if ( event->xproperty.atom == tqt_clipboard_sentinel ) {
if (qt_check_clipboard_sentinel() )
emit clipboard()->dataChanged();
} else if ( event->xproperty.atom == qt_selection_sentinel ) {
@@ -3493,7 +3493,7 @@ int TQApplication::x11ProcessEvent( XEvent* event )
widget = keywidget; // send XKeyEvents through keywidget->x11Event()
if ( app_do_modal ) // modal event handling
- if ( !qt_try_modal(widget, event) ) {
+ if ( !tqt_try_modal(widget, event) ) {
if ( event->type == ClientMessage )
x11ClientMessage( widget, event, TRUE );
return 1;
@@ -3638,7 +3638,7 @@ int TQApplication::x11ProcessEvent( XEvent* event )
if ( qt_focus_model == FocusModel_PointerRoot ) // PointerRoot mode
setActiveWindow( widget );
}
- qt_dispatchEnterLeave( widget, TQWidget::find( curWin ) );
+ tqt_dispatchEnterLeave( widget, TQWidget::find( curWin ) );
curWin = widget->winId();
widget->translateMouseEvent( event ); //we don't get MotionNotify, emulate it
}
@@ -3689,9 +3689,9 @@ int TQApplication::x11ProcessEvent( XEvent* event )
}
if ( !curWin )
- qt_dispatchEnterLeave( widget, 0 );
+ tqt_dispatchEnterLeave( widget, 0 );
- qt_dispatchEnterLeave( enter, widget );
+ tqt_dispatchEnterLeave( enter, widget );
curWin = enter ? enter->winId() : 0;
}
break;
@@ -3761,9 +3761,9 @@ int TQApplication::x11ProcessEvent( XEvent* event )
if ( qt_xdnd_selection && req->selection == qt_xdnd_selection ) {
qt_xdnd_handle_selection_request( req );
- } else if (qt_clipboard) {
+ } else if (tqt_clipboard) {
TQCustomEvent e( TQEvent::Clipboard, event );
- TQApplication::sendSpontaneousEvent( qt_clipboard, &e );
+ TQApplication::sendSpontaneousEvent( tqt_clipboard, &e );
}
break;
}
@@ -3773,9 +3773,9 @@ int TQApplication::x11ProcessEvent( XEvent* event )
if (! req || qt_xdnd_selection && req->selection == qt_xdnd_selection)
break;
- if (qt_clipboard) {
+ if (tqt_clipboard) {
TQCustomEvent e( TQEvent::Clipboard, event );
- TQApplication::sendSpontaneousEvent( qt_clipboard, &e );
+ TQApplication::sendSpontaneousEvent( tqt_clipboard, &e );
}
break;
}
@@ -3786,9 +3786,9 @@ int TQApplication::x11ProcessEvent( XEvent* event )
if (! req || qt_xdnd_selection && req->selection == qt_xdnd_selection)
break;
- if (qt_clipboard) {
+ if (tqt_clipboard) {
TQCustomEvent e( TQEvent::Clipboard, event );
- TQApplication::sendSpontaneousEvent( qt_clipboard, &e );
+ TQApplication::sendSpontaneousEvent( tqt_clipboard, &e );
}
break;
}
@@ -3826,12 +3826,12 @@ bool TQApplication::x11EventFilter( XEvent * )
A modal widget without a parent becomes application-modal.
A modal widget with a parent becomes modal to its parent and grandparents..
- qt_enter_modal()
+ tqt_enter_modal()
Enters modal state
Arguments:
TQWidget *widget A modal widget
- qt_leave_modal()
+ tqt_leave_modal()
Leaves modal state for a widget
Arguments:
TQWidget *widget A modal widget
@@ -3842,38 +3842,38 @@ bool tqt_modal_state()
return app_do_modal;
}
-void qt_enter_modal( TQWidget *widget )
+void tqt_enter_modal( TQWidget *widget )
{
- if ( !qt_modal_stack ) { // create modal stack
- qt_modal_stack = new TQWidgetList;
- TQ_CHECK_PTR( qt_modal_stack );
+ if ( !tqt_modal_stack ) { // create modal stack
+ tqt_modal_stack = new TQWidgetList;
+ TQ_CHECK_PTR( tqt_modal_stack );
}
if (widget->parentWidget()) {
TQEvent e(TQEvent::WindowBlocked);
TQApplication::sendEvent(widget->parentWidget(), &e);
}
- qt_dispatchEnterLeave( 0, TQWidget::find((WId)curWin) );
- qt_modal_stack->insert( 0, widget );
+ tqt_dispatchEnterLeave( 0, TQWidget::find((WId)curWin) );
+ tqt_modal_stack->insert( 0, widget );
app_do_modal = TRUE;
curWin = 0;
ignoreNextMouseReleaseEvent = FALSE;
}
-void qt_leave_modal( TQWidget *widget )
+void tqt_leave_modal( TQWidget *widget )
{
- if ( qt_modal_stack && qt_modal_stack->removeRef(widget) ) {
- if ( qt_modal_stack->isEmpty() ) {
- delete qt_modal_stack;
- qt_modal_stack = 0;
+ if ( tqt_modal_stack && tqt_modal_stack->removeRef(widget) ) {
+ if ( tqt_modal_stack->isEmpty() ) {
+ delete tqt_modal_stack;
+ tqt_modal_stack = 0;
TQPoint p( TQCursor::pos() );
TQWidget* w = TQApplication::widgetAt( p.x(), p.y(), TRUE );
- qt_dispatchEnterLeave( w, TQWidget::find( curWin ) ); // send synthetic enter event
+ tqt_dispatchEnterLeave( w, TQWidget::find( curWin ) ); // send synthetic enter event
curWin = w? w->winId() : 0;
}
}
- app_do_modal = qt_modal_stack != 0;
+ app_do_modal = tqt_modal_stack != 0;
ignoreNextMouseReleaseEvent = TRUE;
if (widget->parentWidget()) {
@@ -3883,7 +3883,7 @@ void qt_leave_modal( TQWidget *widget )
}
-Q_EXPORT bool qt_try_modal( TQWidget *widget, XEvent *event )
+Q_EXPORT bool tqt_try_modal( TQWidget *widget, XEvent *event )
{
if (qt_xdnd_dragging) {
// allow mouse events while DnD is active
@@ -3897,7 +3897,7 @@ Q_EXPORT bool qt_try_modal( TQWidget *widget, XEvent *event )
}
}
- if ( qt_tryModalHelper( widget ) )
+ if ( tqt_tryModalHelper( widget ) )
return TRUE;
bool block_event = FALSE;
@@ -5571,7 +5571,7 @@ bool TQETWidget::translateKeyEvent( const XEvent *event, bool grab )
// send accel events if the keyboard is not grabbed
TQKeyEvent a( type, code, ascii, state, text, autor,
TQMAX( TQMAX(count,1), int(text.length())) );
- if ( qt_tryAccelEvent( this, &a ) )
+ if ( tqt_tryAccelEvent( this, &a ) )
return TRUE;
}
diff --git a/src/kernel/qasyncimageio.cpp b/src/kernel/qasyncimageio.cpp
index 277a2e08..c42e876e 100644
--- a/src/kernel/qasyncimageio.cpp
+++ b/src/kernel/qasyncimageio.cpp
@@ -46,8 +46,8 @@
#include "ntqgif.h"
#include <stdlib.h>
-extern void qt_init_image_handlers();
-extern void qt_init_image_plugins();
+extern void tqt_init_image_handlers();
+extern void tqt_init_image_plugins();
#define Q_TRANSPARENT 0x00ffffff
@@ -303,7 +303,7 @@ public:
#if defined(QT_BUILTIN_GIF_READER) && QT_BUILTIN_GIF_READER == 1
gif_decoder_factory = new TQGIFFormatType;
#endif
- qt_init_image_handlers();
+ tqt_init_image_handlers();
tqAddPostRoutine( cleanup );
}
}
@@ -344,7 +344,7 @@ void TQImageDecoderPrivate::cleanup()
*/
TQImageDecoder::TQImageDecoder(TQImageConsumer* c)
{
- qt_init_image_handlers();
+ tqt_init_image_handlers();
d = new TQImageDecoderPrivate;
TQ_CHECK_PTR(d);
consumer = c;
@@ -397,7 +397,7 @@ int TQImageDecoder::decode(const uchar* buffer, int length)
actual_decoder = f->decoderFor(d->header, d->count);
}
if ( !actual_decoder && !plugins_loaded) {
- qt_init_image_plugins();
+ tqt_init_image_plugins();
plugins_loaded = TRUE;
for (TQImageFormatType* f = TQImageDecoderPrivate::factories->first();
@@ -432,7 +432,7 @@ int TQImageDecoder::decode(const uchar* buffer, int length)
TQImageFormatType* TQImageDecoder::format( const char* name )
{
TQImageDecoderPrivate::ensureFactories();
- qt_init_image_plugins();
+ tqt_init_image_plugins();
for (TQImageFormatType* f = TQImageDecoderPrivate::factories->first();
f;
@@ -467,7 +467,7 @@ const char* TQImageDecoder::formatName(const uchar* buffer, int length)
}
}
if ( !name && !plugins_loaded) {
- qt_init_image_plugins();
+ tqt_init_image_plugins();
plugins_loaded = TRUE;
for (TQImageFormatType* f = TQImageDecoderPrivate::factories->first();
f && !name;
@@ -491,7 +491,7 @@ const char* TQImageDecoder::formatName(const uchar* buffer, int length)
TQStrList TQImageDecoder::inputFormats()
{
TQImageDecoderPrivate::ensureFactories();
- qt_init_image_plugins();
+ tqt_init_image_plugins();
TQStrList result;
diff --git a/src/kernel/qclipboard_x11.cpp b/src/kernel/qclipboard_x11.cpp
index b80e8698..9fd48c58 100644
--- a/src/kernel/qclipboard_x11.cpp
+++ b/src/kernel/qclipboard_x11.cpp
@@ -91,7 +91,7 @@ extern Time tqt_x_time; // def. in qapplication_x11.cpp
extern Time qt_x_incr; // def. in qapplication_x11.cpp
extern Atom qt_xa_clipboard;
extern Atom qt_selection_property;
-extern Atom qt_clipboard_sentinel;
+extern Atom tqt_clipboard_sentinel;
extern Atom qt_selection_sentinel;
extern Atom qt_utf8_string;
@@ -244,7 +244,7 @@ static TQClipboardData *clipboardData()
return internalCbData;
}
-void qt_clipboard_cleanup_mime_source(TQMimeSource *src)
+void tqt_clipboard_cleanup_mime_source(TQMimeSource *src)
{
if(internalCbData && internalCbData->source() == src)
internalCbData->clear(FALSE);
@@ -1520,7 +1520,7 @@ void TQClipboard::setData( TQMimeSource* src, Mode mode )
case Clipboard:
atom = qt_xa_clipboard;
- sentinel_atom = qt_clipboard_sentinel;
+ sentinel_atom = tqt_clipboard_sentinel;
d = clipboardData();
break;
@@ -1644,7 +1644,7 @@ bool qt_check_clipboard_sentinel()
if (XGetWindowProperty(TQPaintDevice::x11AppDisplay(),
TQApplication::desktop()->screen(0)->winId(),
- qt_clipboard_sentinel, 0, 2, False, XA_WINDOW,
+ tqt_clipboard_sentinel, 0, 2, False, XA_WINDOW,
&actualType, &actualFormat, &nitems, &bytesLeft,
(unsigned char **) &owners) == Success) {
if (actualType == XA_WINDOW && actualFormat == 32 && nitems == 2) {
diff --git a/src/kernel/qdnd_x11.cpp b/src/kernel/qdnd_x11.cpp
index aeb02583..e45341aa 100644
--- a/src/kernel/qdnd_x11.cpp
+++ b/src/kernel/qdnd_x11.cpp
@@ -74,8 +74,8 @@ extern "C" {
extern void qt_ignore_badwindow();
extern bool qt_badwindow();
-extern void qt_enter_modal( TQWidget *widget );
-extern void qt_leave_modal( TQWidget *widget );
+extern void tqt_enter_modal( TQWidget *widget );
+extern void tqt_leave_modal( TQWidget *widget );
#if defined(Q_C_CALLBACKS)
}
diff --git a/src/kernel/qeventloop_x11.cpp b/src/kernel/qeventloop_x11.cpp
index bada85fd..0ae38705 100644
--- a/src/kernel/qeventloop_x11.cpp
+++ b/src/kernel/qeventloop_x11.cpp
@@ -60,7 +60,7 @@ static const int XKeyRelease = KeyRelease;
#undef KeyRelease
// from qapplication.cpp
-extern bool qt_is_gui_used;
+extern bool tqt_is_gui_used;
// from qeventloop_unix.cpp
extern timeval *qt_wait_timer();
@@ -117,7 +117,7 @@ void TQEventLoop::init()
// intitialize the X11 parts of the event loop
d->xfd = -1;
- if ( qt_is_gui_used )
+ if ( tqt_is_gui_used )
d->xfd = XConnectionNumber( TQPaintDevice::x11AppDisplay() );
}
@@ -139,11 +139,11 @@ bool TQEventLoop::processEvents( ProcessEventsFlags flags )
int nevents = 0;
#if defined(QT_THREAD_SUPPORT)
- TQMutexLocker locker( TQApplication::qt_mutex );
+ TQMutexLocker locker( TQApplication::tqt_mutex );
#endif
// handle gui and posted events
- if ( qt_is_gui_used ) {
+ if ( tqt_is_gui_used ) {
TQApplication::sendPostedEvents();
// Two loops so that posted events accumulate
@@ -261,7 +261,7 @@ bool TQEventLoop::processEvents( ProcessEventsFlags flags )
FD_ZERO( &d->sn_vec[2].select_fds );
}
- if ( qt_is_gui_used ) {
+ if ( tqt_is_gui_used ) {
// select for events on the event socket - only on X11
FD_SET( d->xfd, &d->sn_vec[0].select_fds );
highest = TQMAX( highest, d->xfd );
@@ -407,7 +407,7 @@ bool TQEventLoop::hasPendingEvents() const
void TQEventLoop::appStartingUp()
{
- if ( qt_is_gui_used )
+ if ( tqt_is_gui_used )
d->xfd = XConnectionNumber( TQPaintDevice::x11AppDisplay() );
}
diff --git a/src/kernel/qimage.cpp b/src/kernel/qimage.cpp
index c67c463a..fad12bfa 100644
--- a/src/kernel/qimage.cpp
+++ b/src/kernel/qimage.cpp
@@ -3861,7 +3861,7 @@ static TQPluginManager<TQImageFormatInterface> *plugin_manager = 0;
static void *plugin_manager = 0;
#endif
-void qt_init_image_plugins()
+void tqt_init_image_plugins()
{
#ifndef QT_NO_COMPONENT
if ( plugin_manager )
@@ -3893,7 +3893,7 @@ static void cleanup()
#endif
}
-void qt_init_image_handlers() // initialize image handlers
+void tqt_init_image_handlers() // initialize image handlers
{
if ( !imageHandlers ) {
imageHandlers = new TQIHList;
@@ -3940,8 +3940,8 @@ void qt_init_image_handlers() // initialize image handlers
static TQImageHandler *get_image_handler( const char *format )
{ // get pointer to handler
- qt_init_image_handlers();
- qt_init_image_plugins();
+ tqt_init_image_handlers();
+ tqt_init_image_plugins();
register TQImageHandler *p = imageHandlers->first();
while ( p ) { // traverse list
if ( p->format == format )
@@ -4012,7 +4012,7 @@ void TQImageIO::defineIOHandler( const char *format,
image_io_handler readImage,
image_io_handler writeImage )
{
- qt_init_image_handlers();
+ tqt_init_image_handlers();
TQImageHandler *p;
p = new TQImageHandler( format, header, flags,
readImage, writeImage );
@@ -4278,8 +4278,8 @@ const char *TQImageIO::imageFormat( TQIODevice *d )
char buf[buflen];
char buf2[buflen];
- qt_init_image_handlers();
- qt_init_image_plugins();
+ tqt_init_image_handlers();
+ tqt_init_image_plugins();
int pos = d->at(); // save position
int rdlen = d->readBlock( buf, buflen ); // read a few bytes
@@ -4326,8 +4326,8 @@ TQStrList TQImageIO::inputFormats()
{
TQStrList result;
- qt_init_image_handlers();
- qt_init_image_plugins();
+ tqt_init_image_handlers();
+ tqt_init_image_plugins();
#ifndef QT_NO_ASYNC_IMAGE_IO
// Include asynchronous loaders first.
@@ -4356,8 +4356,8 @@ TQStrList TQImageIO::outputFormats()
{
TQStrList result;
- qt_init_image_handlers();
- qt_init_image_plugins();
+ tqt_init_image_handlers();
+ tqt_init_image_plugins();
// Include asynchronous writers (!) first.
// (None)
@@ -4497,7 +4497,7 @@ bool TQImageIO::write()
return FALSE;
TQImageHandler *h = get_image_handler( frmt );
if ( !h && !plugin_manager) {
- qt_init_image_plugins();
+ tqt_init_image_plugins();
h = get_image_handler( frmt );
}
if ( !h || !h->write_image ) {
diff --git a/src/kernel/qjpegio.cpp b/src/kernel/qjpegio.cpp
index cbc469fa..8e2f3e2e 100644
--- a/src/kernel/qjpegio.cpp
+++ b/src/kernel/qjpegio.cpp
@@ -105,7 +105,7 @@ extern "C" {
#endif
static
-void qt_init_source(j_decompress_ptr)
+void tqt_init_source(j_decompress_ptr)
{
}
@@ -168,7 +168,7 @@ void qt_term_source(j_decompress_ptr)
inline my_jpeg_source_mgr::my_jpeg_source_mgr(TQImageIO* iioptr)
{
- jpeg_source_mgr::init_source = qt_init_source;
+ jpeg_source_mgr::init_source = tqt_init_source;
jpeg_source_mgr::fill_input_buffer = qt_fill_input_buffer;
jpeg_source_mgr::skip_input_data = qt_skip_input_data;
jpeg_source_mgr::resync_to_restart = jpeg_resync_to_restart;
@@ -376,7 +376,7 @@ extern "C" {
#endif
static
-void qt_init_destination(j_compress_ptr)
+void tqt_init_destination(j_compress_ptr)
{
}
@@ -433,7 +433,7 @@ void qt_term_destination(j_compress_ptr cinfo)
inline
my_jpeg_destination_mgr::my_jpeg_destination_mgr(TQImageIO* iioptr)
{
- jpeg_destination_mgr::init_destination = qt_init_destination;
+ jpeg_destination_mgr::init_destination = tqt_init_destination;
jpeg_destination_mgr::empty_output_buffer = qt_empty_output_buffer;
jpeg_destination_mgr::term_destination = qt_term_destination;
iio = iioptr;
diff --git a/src/kernel/qmetaobject.cpp b/src/kernel/qmetaobject.cpp
index 6dbc044a..75bd9b5a 100644
--- a/src/kernel/qmetaobject.cpp
+++ b/src/kernel/qmetaobject.cpp
@@ -145,7 +145,7 @@ public:
#ifndef QT_NO_PROPERTIES
enumData(0), numEnumData(0),
propData(0),numPropData(0),
- qt_static_property(0),
+ tqt_static_property(0),
#endif
classInfo(0), numClassInfo(0) {}
#ifndef QT_NO_PROPERTIES
@@ -153,7 +153,7 @@ public:
int numEnumData;
const TQMetaProperty *propData;
int numPropData;
- bool (*qt_static_property)(TQObject*, int, int, TQVariant*);
+ bool (*tqt_static_property)(TQObject*, int, int, TQVariant*);
#endif
const TQClassInfo *classInfo;
int numClassInfo;
@@ -249,7 +249,7 @@ TQMetaObject::TQMetaObject( const char *const class_name, TQMetaObject *super_cl
const TQMetaData *const signal_data, int n_signals,
const TQMetaProperty *const prop_data, int n_props,
const TQMetaEnum *const enum_data, int n_enums,
- bool (*qt_static_property)(TQObject*, int, int, TQVariant*),
+ bool (*tqt_static_property)(TQObject*, int, int, TQVariant*),
const TQClassInfo *const class_info, int n_info )
{
classname = class_name; // set meta data
@@ -265,7 +265,7 @@ TQMetaObject::TQMetaObject( const char *const class_name, TQMetaObject *super_cl
d->numPropData = n_props;
d->enumData = enum_data;
d->numEnumData = n_enums;
- d->qt_static_property = qt_static_property;
+ d->tqt_static_property = tqt_static_property;
d->classInfo = class_info;
d->numClassInfo = n_info;
@@ -492,14 +492,14 @@ TQMetaObject *TQMetaObject::new_metaobject( const char *classname,
const TQMetaData * const signal_data, int n_signals,
const TQMetaProperty * const prop_data, int n_props,
const TQMetaEnum * const enum_data, int n_enums,
- bool (*qt_static_property)(TQObject*, int, int, TQVariant*),
+ bool (*tqt_static_property)(TQObject*, int, int, TQVariant*),
const TQClassInfo * const class_info, int n_info )
{
return new TQMetaObject( classname, superclassobject, slot_data, n_slots,
signal_data, n_signals,
prop_data, n_props,
enum_data, n_enums,
- qt_static_property,
+ tqt_static_property,
class_info, n_info );
}
#endif
@@ -827,14 +827,14 @@ bool TQMetaObject::hasMetaObject( const char *class_name )
### this functions will go away. It exists purely for the sake of meta
### object code generated with TQt 3.1.0
*/
-bool TQMetaObject::qt_static_property( TQObject* o, int id, int f, TQVariant* v)
+bool TQMetaObject::tqt_static_property( TQObject* o, int id, int f, TQVariant* v)
{
- if ( d->qt_static_property )
- return d->qt_static_property( o, id, f, v );
+ if ( d->tqt_static_property )
+ return d->tqt_static_property( o, id, f, v );
else if ( o ) // compatibility
- return o->qt_property( id, f, v );
+ return o->tqt_property( id, f, v );
else if ( superclass )
- return superclass->qt_static_property( o, id, f, v );
+ return superclass->tqt_static_property( o, id, f, v );
switch ( f ) {
case 3: case 4: case 5:
return TRUE;
@@ -1116,7 +1116,7 @@ bool TQMetaProperty::designable( TQObject* o ) const
return FALSE;
if ( o ) {
int idx = _id >= 0 ? _id : (*meta)->indexOfProperty( this, TRUE );
- return idx >= 0 && o->qt_property( idx, 3, 0 );
+ return idx >= 0 && o->tqt_property( idx, 3, 0 );
}
if ( testFlags( DesignableOverride ) ) {
const TQMetaObject* mo = (*meta);
@@ -1137,7 +1137,7 @@ bool TQMetaProperty::scriptable( TQObject* o ) const
{
if ( o ) {
int idx = _id >= 0 ? _id : (*meta)->indexOfProperty( this, TRUE );
- return idx >= 0 && o->qt_property( idx, 4, 0 );
+ return idx >= 0 && o->tqt_property( idx, 4, 0 );
}
if ( testFlags( ScriptableOverride ) ) {
const TQMetaObject* mo = (*meta);
@@ -1160,7 +1160,7 @@ bool TQMetaProperty::stored( TQObject* o ) const
return FALSE;
if ( o ) {
int idx = _id >= 0 ? _id : (*meta)->indexOfProperty( this, TRUE );
- return idx >= 0 && o->qt_property( idx, 5, 0 );
+ return idx >= 0 && o->tqt_property( idx, 5, 0 );
}
if ( testFlags( StoredOverride ) ) {
const TQMetaObject* mo = (*meta);
@@ -1185,7 +1185,7 @@ bool TQMetaProperty::reset( TQObject* o ) const
int idx = _id >= 0 ? _id : (*meta)->indexOfProperty( this, TRUE );
if ( idx < 0 )
return 0;
- return o->qt_property( idx, 2, 0 );
+ return o->tqt_property( idx, 2, 0 );
}
diff --git a/src/kernel/qmime.cpp b/src/kernel/qmime.cpp
index d36b88ae..8b962a64 100644
--- a/src/kernel/qmime.cpp
+++ b/src/kernel/qmime.cpp
@@ -110,8 +110,8 @@ void TQMimeSource::clearCache()
TQMimeSource::~TQMimeSource()
{
#ifndef QT_NO_CLIPBOARD
- extern void qt_clipboard_cleanup_mime_source(TQMimeSource *);
- qt_clipboard_cleanup_mime_source(this);
+ extern void tqt_clipboard_cleanup_mime_source(TQMimeSource *);
+ tqt_clipboard_cleanup_mime_source(this);
#endif
clearCache();
}
diff --git a/src/kernel/qpixmap_x11.cpp b/src/kernel/qpixmap_x11.cpp
index 328f7817..fb4168aa 100644
--- a/src/kernel/qpixmap_x11.cpp
+++ b/src/kernel/qpixmap_x11.cpp
@@ -112,7 +112,7 @@ static XShmSegmentInfo xshminfo;
static XImage *xshmimg = 0;
static Pixmap xshmpm = 0;
-static void qt_cleanup_mitshm()
+static void tqt_cleanup_mitshm()
{
if ( xshmimg == 0 )
return;
@@ -137,11 +137,11 @@ static bool qt_create_mitshm_buffer( const TQPaintDevice* dev, int w, int h )
Visual *vis = (Visual*)dev->x11Visual();
if ( xshminit ) {
- qt_cleanup_mitshm();
+ tqt_cleanup_mitshm();
} else {
if ( !XShmQueryVersion(dpy, &major, &minor, &pixmaps_ok) )
return FALSE; // MIT Shm not supported
- tqAddPostRoutine( qt_cleanup_mitshm );
+ tqAddPostRoutine( tqt_cleanup_mitshm );
xshminit = TRUE;
}
diff --git a/src/kernel/qrichtext.cpp b/src/kernel/qrichtext.cpp
index 59f13022..42bcc9d2 100644
--- a/src/kernel/qrichtext.cpp
+++ b/src/kernel/qrichtext.cpp
@@ -7219,7 +7219,7 @@ static const Entity entitylist [] = {
static TQMap<TQString, TQChar> *html_map = 0;
-static void qt_cleanup_html_map()
+static void tqt_cleanup_html_map()
{
delete html_map;
html_map = 0;
@@ -7229,7 +7229,7 @@ static TQMap<TQString, TQChar> *htmlMap()
{
if ( !html_map ) {
html_map = new TQMap<TQString, TQChar>;
- tqAddPostRoutine( qt_cleanup_html_map );
+ tqAddPostRoutine( tqt_cleanup_html_map );
const Entity *ent = entitylist;
while( ent->code ) {
diff --git a/src/kernel/qstylesheet.cpp b/src/kernel/qstylesheet.cpp
index e74a9be1..dcddbb9e 100644
--- a/src/kernel/qstylesheet.cpp
+++ b/src/kernel/qstylesheet.cpp
@@ -1286,7 +1286,7 @@ void TQStyleSheet::init()
static TQStyleSheet* defaultsheet = 0;
-static TQSingleCleanupHandler<TQStyleSheet> qt_cleanup_stylesheet;
+static TQSingleCleanupHandler<TQStyleSheet> tqt_cleanup_stylesheet;
/*!
Returns the application-wide default style sheet. This style sheet
@@ -1302,7 +1302,7 @@ TQStyleSheet* TQStyleSheet::defaultSheet()
{
if (!defaultsheet) {
defaultsheet = new TQStyleSheet();
- qt_cleanup_stylesheet.set( &defaultsheet );
+ tqt_cleanup_stylesheet.set( &defaultsheet );
}
return defaultsheet;
}
@@ -1318,12 +1318,12 @@ void TQStyleSheet::setDefaultSheet( TQStyleSheet* sheet)
{
if ( defaultsheet != sheet ) {
if ( defaultsheet )
- qt_cleanup_stylesheet.reset();
+ tqt_cleanup_stylesheet.reset();
delete defaultsheet;
}
defaultsheet = sheet;
if ( defaultsheet )
- qt_cleanup_stylesheet.set( &defaultsheet );
+ tqt_cleanup_stylesheet.set( &defaultsheet );
}
/*!\internal
diff --git a/src/kernel/qwidget_x11.cpp b/src/kernel/qwidget_x11.cpp
index d2631316..71c36373 100644
--- a/src/kernel/qwidget_x11.cpp
+++ b/src/kernel/qwidget_x11.cpp
@@ -207,7 +207,7 @@ Window qt_XCreateSimpleWindow( const TQWidget *creator,
void qt_XDestroyWindow( const TQWidget *destroyer,
Display *display, Window window );
-Q_EXPORT void qt_x11_enforce_cursor( TQWidget * w )
+Q_EXPORT void tqt_x11_enforce_cursor( TQWidget * w )
{
if ( w->testWState( TQt::WState_OwnCursor ) ) {
TQCursor * oc = TQApplication::overrideCursor();
@@ -225,7 +225,7 @@ Q_EXPORT void qt_x11_enforce_cursor( TQWidget * w )
}
}
-Q_EXPORT void qt_wait_for_window_manager( TQWidget* w )
+Q_EXPORT void tqt_wait_for_window_manager( TQWidget* w )
{
TQApplication::flushX();
XEvent ev;
@@ -754,7 +754,7 @@ void TQWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
} else if ( topLevel ) { // set X cursor
setWState( WState_OwnCursor );
if ( initializeWindow )
- qt_x11_enforce_cursor( this );
+ tqt_x11_enforce_cursor( this );
}
if ( destroyw )
@@ -800,7 +800,7 @@ void TQWidget::destroy( bool destroyWindow, bool destroySubWindows )
if ( isTopLevel() )
qt_deferred_map_take( this );
if ( testWFlags(WShowModal) ) // just be sure we leave modal
- qt_leave_modal( this );
+ tqt_leave_modal( this );
else if ( testWFlags(WType_Popup) )
tqApp->closePopup( this );
@@ -1210,7 +1210,7 @@ void TQWidget::setCursor( const TQCursor &cursor )
extra->curs = new TQCursor(cursor);
}
setWState( WState_OwnCursor );
- qt_x11_enforce_cursor( this );
+ tqt_x11_enforce_cursor( this );
XFlush( x11Display() );
}
@@ -1222,7 +1222,7 @@ void TQWidget::unsetCursor()
}
if ( !isTopLevel() )
clearWState( WState_OwnCursor );
- qt_x11_enforce_cursor( this );
+ tqt_x11_enforce_cursor( this );
XFlush( x11Display() );
}
@@ -1932,7 +1932,7 @@ void TQWidget::showWindow()
&& !(qt_net_supports(qt_net_wm_state_max_h)
&& qt_net_supports(qt_net_wm_state_max_v))) {
XMapWindow( x11Display(), winId() );
- qt_wait_for_window_manager(this);
+ tqt_wait_for_window_manager(this);
// if the wm was not smart enough to adjust our size, do that manually
updateFrameStrut();
@@ -1956,7 +1956,7 @@ void TQWidget::showWindow()
if (isFullScreen() && !qt_net_supports(qt_net_wm_state_fullscreen)) {
XMapWindow(x11Display(), winId());
- qt_wait_for_window_manager(this);
+ tqt_wait_for_window_manager(this);
return;
}
}
diff --git a/src/kernel/qobject.cpp b/src/kernel/qobject.cpp
index e958f636..61ed4e7e 100644
--- a/src/kernel/qobject.cpp
+++ b/src/kernel/qobject.cpp
@@ -246,14 +246,14 @@ static void removeObjFromList( TQObjectList *objList, const TQObject *obj,
Returns 0 if there is no such child.
\code
- TQListBox *c = (TQListBox *) qt_find_obj_child( myWidget, "TQListBox",
+ TQListBox *c = (TQListBox *) tqt_find_obj_child( myWidget, "TQListBox",
"my list box" );
if ( c )
c->insertItem( "another string" );
\endcode
*/
-void *qt_find_obj_child( TQObject *parent, const char *type, const char *name )
+void *tqt_find_obj_child( TQObject *parent, const char *type, const char *name )
{
const TQObjectList *list = parent->children();
if ( list ) {
@@ -303,7 +303,7 @@ static void qt_spy_signal( TQObject* sender, int signal, TQUObject* o )
TQObject* old_sender = qt_spy_signal_sender;
qt_spy_signal_sender = sender;
- tqt_preliminary_signal_spy->qt_invoke( slot, o );
+ tqt_preliminary_signal_spy->tqt_invoke( slot, o );
qt_spy_signal_sender = old_sender;
break;
}
@@ -616,7 +616,7 @@ bool TQObject::inherits( const char *clname ) const
\sa inherits()
*/
-void *qt_inheritedBy( TQMetaObject *superClass, const TQObject *object )
+void *tqt_inheritedBy( TQMetaObject *superClass, const TQObject *object )
{
if (!object)
return 0;
@@ -2378,9 +2378,9 @@ void TQObject::activate_signal( TQConnectionList *clist, TQUObject *o )
sol->currentSender = this;
}
if ( c->memberType() == TQSIGNAL_CODE )
- object->qt_emit( c->member(), o );
+ object->tqt_emit( c->member(), o );
else
- object->qt_invoke( c->member(), o );
+ object->tqt_invoke( c->member(), o );
if ( sol ) {
sol->currentSender = oldSender;
if ( sol->deref() )
@@ -2402,9 +2402,9 @@ void TQObject::activate_signal( TQConnectionList *clist, TQUObject *o )
sol->currentSender = this;
}
if ( c->memberType() == TQSIGNAL_CODE )
- object->qt_emit( c->member(), o );
+ object->tqt_emit( c->member(), o );
else
- object->qt_invoke( c->member(), o );
+ object->tqt_invoke( c->member(), o );
if (sol ) {
sol->currentSender = oldSender;
if ( sol->deref() )
@@ -2631,7 +2631,7 @@ bool TQObject::setProperty( const char *name, const TQVariant& value )
} else if ( v.type() != TQVariant::Int && v.type() != TQVariant::UInt ) {
return FALSE;
}
- return qt_property( id, 0, &v );
+ return tqt_property( id, 0, &v );
}
TQVariant::Type type = (TQVariant::Type)(p->flags >> 24);
@@ -2639,7 +2639,7 @@ bool TQObject::setProperty( const char *name, const TQVariant& value )
type = TQVariant::nameToType( p->type() );
if ( type != TQVariant::Invalid && !v.canCast( type ) )
return FALSE;
- return qt_property( id, 0, &v );
+ return tqt_property( id, 0, &v );
}
/*!
@@ -2666,8 +2666,8 @@ TQVariant TQObject::property( const char *name ) const
className(), name );
return v;
}
- TQObject* that = (TQObject*) this; // moc ensures constness for the qt_property call
- that->qt_property( id, 1, &v );
+ TQObject* that = (TQObject*) this; // moc ensures constness for the tqt_property call
+ that->tqt_property( id, 1, &v );
return v;
}
diff --git a/src/kernel/qwidget.cpp b/src/kernel/qwidget.cpp
index 5a27310f..a29036c1 100644
--- a/src/kernel/qwidget.cpp
+++ b/src/kernel/qwidget.cpp
@@ -1760,8 +1760,8 @@ void TQWidget::setEnabled( bool enable )
// enforce the windows behavior of clearing the cursor on
// disabled widgets
- extern void qt_x11_enforce_cursor( TQWidget * w ); // defined in qwidget_x11.cpp
- qt_x11_enforce_cursor( this );
+ extern void tqt_x11_enforce_cursor( TQWidget * w ); // defined in qwidget_x11.cpp
+ tqt_x11_enforce_cursor( this );
}
#endif
#ifdef Q_WS_WIN
@@ -4044,9 +4044,9 @@ void TQWidget::show()
TQApplication::sendEvent( this, &showEvent );
if ( testWFlags(WShowModal) ) {
// qt_enter_modal *before* show, otherwise the initial
// stacking might be wrong
- qt_enter_modal( this );
+ tqt_enter_modal( this );
}
// do not show the window directly, but post a show-window request
@@ -4096,7 +4096,7 @@ void TQWidget::hide()
// destroyed and we lose all access to its parent because we haven't
// left modality. (Eg. modal Progress Dialog)
if ( testWFlags(WShowModal) )
- qt_leave_modal( this );
+ tqt_leave_modal( this );
#if defined(Q_WS_WIN)
if ( isTopLevel() && !isPopup() && parentWidget() && isActiveWindow() )
@@ -4940,7 +4940,7 @@ bool TQWidget::event( TQEvent *e )
if ( e->type() == TQEvent::LanguageChange ) {
int index = metaObject()->findSlot( "languageChange()", TRUE );
if ( index >= 0 )
- qt_invoke( index, 0 );
+ tqt_invoke( index, 0 );
}
update();
break;
@@ -4985,7 +4985,7 @@ bool TQWidget::event( TQEvent *e )
TQObject *o;
while( ( o = it.current() ) != 0 ) {
++it;
- TQWidget *w = ::qt_cast<TQWidget*>(o);
+ TQWidget *w = ::tqt_cast<TQWidget*>(o);
if (w && !w->testWFlags(TQt::WShowModal))
TQApplication::sendEvent( o, e );
}
@@ -4044,9 +4044,9 @@ void TQWidget::show()
TQApplication::sendEvent( this, &showEvent );
if ( testWFlags(WShowModal) ) {
- // qt_enter_modal *before* show, otherwise the initial
+ // tqt_enter_modal *before* show, otherwise the initial
// stacking might be wrong